@@ -1,11 +1,10 @@
 from os import path
-from pmanager.res import get_home_dir_path, perror, pinfo, sanitize_for_xml
-
+from pmanager.res import *
 
 def initialize(namespace):
 
 
-    project_name = namespace.project_name[0]
+    project_name = namespace.project_name
     command = sanitize_for_xml(namespace.command[0])
 
 
@@ -21,6 +20,7 @@ def initialize(namespace):
             dirpath = f.read()+"/"+ project_name +"/"
             f.close()
 
+
     #check if the project exists
     if not path.exists(dirpath):
         perror("This project does not exists")
