@@ -5,7 +5,7 @@ from pmanager.res import *
 
 def initialize(namespace):
     
-    project_name = namespace.project_name[0]
+    project_name = namespace.project_name
 
     if not path.exists("config/default_path.conf"):
 
