@@ -1,9 +1,13 @@
-from git import Repo
+try:
+    from git import Repo
+except ImportError:
+    pass
+    
 from pmanager.res import *
 
 def initialize(namespace):
 
-    project_name = namespace.project_name[0]
+    project_name = namespace.project_name
     git_url = namespace.git_url[0]
 
     if not path.exists("config/default_path.conf"):
@@ -13,7 +17,7 @@ def initialize(namespace):
             dirpath = f.read()+"/"+ project_name
 
     if path.exists(dirpath):
-        perror(f"This project does not exist : \n {dirpath}")
+        perror(f"This project already exists : \n {dirpath}")
         exit(1)
 
     try:
