@@ -3,7 +3,7 @@ from pmanager.res import perror, get_home_dir_path, psuccess
 from subprocess import run
 
 def initialize(namespace):
-    project_name = namespace.project_name[0]
+    project_name = namespace.project_name
 
 
     if not path.exists("config/default_path.conf"):
