@@ -21,7 +21,7 @@ def run_cmd(cmd):
 def initialize(namespace):
 
 
-    project_name = namespace.project_name[0]
+    project_name = namespace.project_name
 
     if not path.exists("config/default_path.conf"):
 
@@ -33,7 +33,28 @@ def initialize(namespace):
 
             dirpath = f.read()+"/"+ project_name +"/"
 
-    pinfo(f"opening project folder : \n {dirpath}")
+
+
+
+    #check if the project exists
+    if not path.exists(dirpath):
+        perror("This project does not exists")
+        exit(0)
+
+    
+    pinfo(f"opening project folder in terminal : \n {dirpath}")
+    
+    
+    if path.exists("config/default_term.conf"):
+        pinfo("Custom terminal command detected")
+        with open("config/default_term.conf","r",encoding="utf-8") as f:
+            sTermCmd = f.read()
+            pinfo(f"running : {sTermCmd} \"{dirpath}\"")
+            Process(run_cmd(f"{sTermCmd} \"{dirpath}\"")).start()
+            f.close()
+
+        return
+
     
     
     DEBIAN_BASED_DISTRO = ["debian","ubuntu","linuxmint","kali","raspbian","deepin","antix","parrot","devuan","av"]
@@ -77,4 +98,4 @@ def initialize(namespace):
     
     
     elif system() == "Windows":
-        run(["start", "cmd.exe", f"@cmd /k cd {dirpath}"],shell=True)
\ No newline at end of file
+        run(["start","cmd.exe","/max", f"/k cd /d {dirpath}"],shell=True)
\ No newline at end of file
